@@ -6,7 +6,7 @@
  *
  * Created 9 May 1998
  * Bert Bos <bert@w3.org>
- * $Id: hxnormalize.c,v 1.25 2019/10/05 17:11:31 bbos Exp $
+ * $Id: hxnormalize.c,v 1.27 2023/01/23 21:19:41 bbos Exp $
  */
 #include "config.h"
 #include <stdio.h>
@@ -21,6 +21,8 @@
 #  include <strings.h>
 #endif
 #include <assert.h>
+#include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #include "export.h"
 #include "types.e"
@@ -30,7 +32,6 @@
 #include "textwrap.e"
 #include "dict.e"
 #include "openurl.e"
-#include "errexit.e"
 #include "langinfo.e"
 
 static Tree tree;
@@ -138,29 +139,6 @@ void handle_endtag(void *clientdata, string name)
   free(name);
 }
 
-/* insert -- insert an attribute into a sorted list of attributes */
-static pairlist insert(pairlist x, pairlist list)
-{
-  if (! list) {					/* Empty list */
-    x->next = NULL;
-    return x;
-  } else if (strcmp(x->name, list->name) <= 0) { /* Insert at head */
-    x->next = list;
-    return x;
-  } else {					/* Insert not at head */
-    list->next = insert(x, list->next);
-    return list;
-  }
-}
-
-/* sort_list -- sort a linked list of attributes, return reordered list */
-static pairlist sort_list(pairlist list)
-{
-  /* Insertion sort should be fast enough... */
-  if (! list) return NULL;
-  else return insert(list, sort_list(list->next));
-}
-
 /* next_ambiguous -- check if omitting end changes the meaning */
 static bool next_ambiguous(Node *n)
 {
@@ -270,7 +248,7 @@ static void pp(Tree n, bool preformatted, bool allow_text,
       if (!preformatted && break_before(n->name)) outln(NULL, false, true);
       out("<", preformatted, true); out(n->name, preformatted, true);
       if (break_before(n->name)) inc_indent();
-      n->attribs = sort_list(n->attribs);
+      n->attribs = pairlist_sort(n->attribs);
       for (h = n->attribs; h != NULL; h = h->next) {
 	out(" ", false, true); out(h->name, false, true);
 	if (do_xml) {
@@ -326,8 +304,8 @@ static void pp(Tree n, bool preformatted, bool allow_text,
 	out(">", preformatted, true);
 	for (l = n->children; l != NULL; l = l->sister) {
 	  if (l->tp != Text) {
-	    errexit("Cannot convert <%s> to HTML because it has children\n",
-		    n->name);
+	    errx(EX_DATAERR,
+	      "Cannot convert <%s> to HTML because it has children", n->name);
 	  } else if (hasprefix(l->text, "<![CDATA[")) {
 	    assert(hasaffix(l->text, "]]>"));
 	    s = l->text + 9;	/* Skip "<![CDATA[" */
@@ -410,8 +388,8 @@ int main(int argc, char *argv[])
   if (optind == argc) yyin = stdin;
   else if (optind == argc - 1) yyin = fopenurl(argv[optind], "r", &status);
   else usage(argv[0]);
-  if (yyin == NULL) {perror(argv[optind]); exit(2);}
-  if (status != 200) errexit("%s : %s\n", argv[optind], http_strerror(status));
+  if (yyin == NULL) err(EX_IOERR, "%s", argv[optind]);
+  if (status != 200) errx(EX_IOERR,"%s: %s",argv[optind],http_strerror(status));
 
   /* Bind the parser callback routines to our handlers */
   if (input_is_xml) {
