@@ -10,6 +10,8 @@ TMP2=`mktemp /tmp/select18-XXXXXX` || exit 1
 	</div>
 	<p>
 	<a>Second</a>
+	Some text
+	<!-- A comment -->
 	<a>Third</a>
 	<a>Fourth</a>
 	</p>
