@@ -21,12 +21,13 @@
 #endif
 #include <ctype.h>
 #include <stdio.h>
+#include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #include "export.h"
 #include "heap.e"
 #include "types.e"
 #include "dtd.e"
-#include "errexit.e"
 #include "scan.e"
 
 EXPORT typedef enum {
@@ -425,11 +426,13 @@ EXPORT Tree html_push(Tree t, string elem, pairlist attr)
 EXPORT Tree tree_pop(Tree t, string elem)
 {
   assert(t != NULL);
-  if (t->tp == Root) errexit("End tag </%s> without matching start tag\n", elem);
+  if (t->tp == Root)
+    errx(EX_DATAERR, "End tag </%s> without matching start tag", elem);
   assert(t->tp == Element);
   if (*elem == '\0') return pop(t); /* Empty end tag </> */
   if (eq(t->name, elem)) return pop(t);
-  errexit("End tag </%s> doesn't match start tag <%s>\n", elem, t->name);
+  errx(EX_DATAERR, "End tag </%s> doesn't match start tag <%s>",
+    elem, t->name);
   return NULL;			/* Keep lint happy */
 }
 
